@@ -70,12 +70,11 @@ x="-x"
 e="-e"
 output_coverage_option=""
 genotyping="-genotype"
+remove=1
 verbose=1
 clustering="false"
 short_read_connector_path=""
 option_phase_variants=""
-graph_reused="Egg62hdS7knSFvF3" # with -g option, we use a previously created graph. 
-
 
 max_size_cluster=150
 max_missing=0.95
@@ -137,7 +136,7 @@ function help {
     echo ""
     echo "OPTIONS"
     echo "      -g | --graph <file name>"
-    echo "           Reuse a previously created graph (.h5 file)"
+    echo "           reuse a previously created graph (.h5 file) with same prefix and same k and c parameters."
     echo "      -p | --prefix <string>"
     echo "           All out files will start with this prefix. Default=\"discoRes\""
     echo "      -C | --max_coverage <int value>" 
@@ -146,7 +145,7 @@ function help {
     echo "      -l | --no_low_complexity"
     echo "           Remove low complexity bubbles"
     echo "      -D | --deletion_max_size <int value>"
-    echo "           discoSnpRad will search for deletions of size from 0 to D included. Default=0 (no deletion)"
+    echo "           discoSnpRad will search for deletions of size from 1 to D included. Default=0"
     
     echo ""
     echo "CLUSTERING OPTION"
@@ -243,7 +242,6 @@ while :; do
     
     -A) 
         option_phase_variants="-phasing"
-        extend="-t"
         echo "Will phase variants during kissreads process - WARNING this option is too experimental and thus not described in the help message"
         echo "You can obtain clusters using script : \"script/from_phased_alleles_to_clusters.sh file_name_of_phased_alleles\" (the filename(s) is/are given during kissreads process"
         ;;
@@ -289,12 +287,7 @@ while :; do
         ;;
 
     -g|--graph)
-        if [ "$2" ] && [ ${2:0:1} != "-" ] ; then
-            graph_reused=$2
-            shift
-        else
-            die 'ERROR: "'$1'" option requires a non-empty option argument.'
-        fi
+        remove=0
         ;;
 
     -l|--no_low_complexity)
@@ -453,7 +446,7 @@ fi
 if [[ "$clustering" == "true" ]]; then
 	# first tests the directory given by user if any
 	if [ -n "$short_read_connector_path" ]; then
-		src_file="$short_read_connector_path/short_read_connector_linker.sh"
+		src_file="$short_read_connector_path/short_read_connector.sh"
     	if [ -f "$src_file" ]; then
             echo "${yellow}short_read_connector path is $src_file$reset"
     	else
@@ -467,9 +460,9 @@ if [[ "$clustering" == "true" ]]; then
     	fi
     else
     	#then tests if src is in the PATH env variable
-    	src_file=$(command -v short_read_connector_linker.sh)
+    	src_file=$(command -v short_read_connector.sh)
     	if [ -n "$src_file" ]; then
-    		echo "${yellow}short_read_connector_linker path is $src_file$reset"
+    		echo "${yellow}short_read_connector path is $src_file$reset"
     	else
     		echo "${red}               **************************************************************************"
             echo "               ** WARNING: I cannot find short_read_connector in PATH. "
@@ -523,11 +516,8 @@ fi
 if [[ "$wraith" == "false" ]]; then
     echo "${yellow}     Running discoSnpRad "$version", in directory "$EDIR" with following parameters:"
     echo "           read_sets="$read_sets
-    echo "           short_read_connector_linker path="$short_read_connector_path
+    echo "           short_read_connector path="$short_read_connector_path
     echo "           prefix="$h5prefix
-    if [ -f ${graph_reused} ]; then
-        echo "           reuse graph="${graph_reused}
-    fi
     echo "           c="$c
     echo "           C="$C
     echo "           k="$k
@@ -564,9 +554,12 @@ fi
 ############################################################
 #################### GRAPH CREATION  #######################
 ############################################################
+if [ $remove -eq 1 ]; then
+    rm -f $h5prefix.h5
+fi
 
 
-if [ ! -f ${graph_reused} ]; then # no graph was given or the given graph was not a file. 
+if [ ! -e $h5prefix.h5 ]; then
     T="$(date +%s)"
     echo "${yellow}     ############################################################"
     echo "     #################### GRAPH CREATION  #######################"
@@ -588,10 +581,9 @@ if [ ! -f ${graph_reused} ]; then # no graph was given or the given graph was no
     if [[ "$wraith" == "false" ]]; then
         echo "${yellow}Graph creation time in seconds: ${T}${reset}"
     fi
-    graph_reused=$h5prefix.h5
 else
     if [[ "$wraith" == "false" ]]; then
-        echo "${yellow}File ${graph_reused} exists. We use it as input graph${reset}"
+        echo "${yellow}File $h5prefix.h5 exists. We use it as input graph${reset}"
     fi
 fi
 
@@ -608,7 +600,7 @@ T="$(date +%s)"
 echo "${yellow}     ############################################################"
 echo "     #################### KISSNP2 MODULE  #######################"
 echo "     ############################################################${reset}"
-kissnp2Cmd="${kissnp2_bin} -in ${graph_reused} -out ${kissprefix}_r  -b $b $l $x -P $P  -D $D $extend $option_cores_gatb $output_coverage_option -coverage_file ${h5prefix}_cov.h5 -max_ambigous_indel ${max_ambigous_indel} -max_symmetrical_crossroads ${option_max_symmetrical_crossroads}  -verbose $verbose -max_truncated_path_length_difference ${max_truncated_path_length_difference}"
+kissnp2Cmd="${kissnp2_bin} -in $h5prefix.h5 -out ${kissprefix}_r  -b $b $l $x -P $P  -D $D $extend $option_cores_gatb $output_coverage_option -coverage_file ${h5prefix}_cov.h5 -max_ambigous_indel ${max_ambigous_indel} -max_symmetrical_crossroads ${option_max_symmetrical_crossroads}  -verbose $verbose -max_truncated_path_length_difference ${max_truncated_path_length_difference}"
 echo $green${kissnp2Cmd}$cyan
 if [[ "$wraith" == "false" ]]; then
     ${kissnp2Cmd}
