@@ -56,15 +56,14 @@ P=3 # number of polymorphsim per bubble
 option_max_symmetrical_crossroads=""
 l="-l"
 extend="-t"
-x="" # if set to -x : authorize non closed bubbles (used mainly in RNA seq)
+x=""
+y=""
 output_coverage_option=""
 genotyping="-genotype"
+remove=1
 verbose=1
 stop_after_kissnp=0
-aav=0 # if set to not zero : considers the aav context: 1/ no uncoherent 2/ authorize -x option 
-e="" # if set to -e: Map variant predictions on reference genome with their unitig or contig extensions
-graph_reused="Egg62hdS7knSFvF3" # with -g option, we use a previously created graph. 
-
+e=""
 #EDIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
 EDIR=$( python -c "import os.path; print(os.path.dirname(os.path.realpath(\"${BASH_SOURCE[0]}\")))" ) # as suggested by Philippe Bordron 
 
@@ -125,10 +124,10 @@ function help {
     echo -e "\t -s | --symmetrical value <int value>"
     echo -e "\t\t In -b 2 mode only: maximal number of symmetrical crossroads traversed while trying to close a bubble. Default: no limit"
     echo -e "\t -g | --graph <file name>"
-    echo -e "\t\t Reuse a previously created graph (.h5 file)"
+    echo -e "\t\t Reuse a previously created graph (.h5 file) with same prefix and same k and c parameters."
     echo -e "\t -X\t Stop discoSnp++ right after variant calling - the output is only a fasta file with no coverage information."
     echo -e "\t -D | --deletion_max_size <int>"
-    echo -e "\t\t discoSnp++ will search for deletions of size from 0 to D included. -D 0 means no deletion detected. Default=100."
+    echo -e "\t\t discoSnp++ will search for deletions of size from 1 to D included. Default=100"
     echo -e "\t -a | --ambiguity_max_size <int>"
     echo -e "\t\t Maximal size of ambiguity of INDELs. INDELS whose ambiguity is higher than this value are not output  [default '20']"
     echo -e "\t -P | --max_snp_per_bubble <int>"
@@ -160,11 +159,8 @@ function help {
     echo -e "\t\t Optional unless option -G used and bwa is not in the binary path."
     echo -e "\t -e\t Map variant predictions on reference genome with their unitig or contig extensions."
     echo -e "\t\t Useless unless mapping on reference genome is required (option -G). "
-
-    echo -e "\nCONTEXT OPTION"
-    echo -e "\t -z\t Considers AAV context: all predictions are coherents and authorize non closed bubbles (-x option)" 
+    echo 
     
-    echo -e "\nMISC."
     echo -e "\t -w\t Wraith mode: only show all discoSnp++ commands without running them"
     echo -e "\t -v <0 or 1>"
     echo -e "\t\t Verbose 0 (avoids progress output) or 1 (enables progress output) -- default=1."
@@ -189,10 +185,6 @@ while :; do
     -X)
         stop_after_kissnp=1
         ;;
-
-    -z)
-        aav=1
-        ;;
     -w)
         wraith="true"
         ;;
@@ -209,7 +201,7 @@ while :; do
             die 'ERROR: "'$1'" option requires a non-empty option argument.'
         fi
         ;;
-
+       
     -v)        
         if [ "$2" ] && [ ${2:0:1} != "-" ] ; then
             verbose=$2
@@ -235,12 +227,7 @@ while :; do
         ;;
 
     -g|--graph)
-        if [ "$2" ] && [ ${2:0:1} != "-" ] ; then
-            graph_reused=$2
-            shift
-        else
-            die 'ERROR: "'$1'" option requires a non-empty option argument.'
-        fi
+        remove=0
         ;;
 
 
@@ -357,7 +344,11 @@ while :; do
         ;;
 
     -x)
-        x="-x" ##Authorise non closed bubbles
+        x="-x" ##CHARLOTTE
+        ;;
+
+    -y)
+        y="-x" ##CHARLOTTE
         ;;
 
     -G|--reference_genome)
@@ -369,8 +360,9 @@ while :; do
         fi
         ;;
 
+
     -e)
-        e="-e" # map with extensions to the reference genome
+        e="-e"
         ;;
 
     -u|--max_threads)
@@ -455,9 +447,6 @@ if [[ "$useref" == "true" ]]; then
 fi
 cat $read_sets >> ${read_sets}_${kissprefix}_removemeplease
 
-if [ $aav -eq 1 ]; then
-    x="-x"
-fi
 
 
 #######################################################################
@@ -478,13 +467,9 @@ if [[ "$wraith" == "false" ]]; then
     if [ ! -z "${read_sets_kissreads}" ]; then
         echo -e "\t fof_mapping read_file_of_files="${read_sets_kissreads}
     fi
-    if [ -f ${graph_reused} ]; then
-        echo -e "\t reuse graph="${graph_reused}
-    fi
     echo -e "\t p="$prefix
     echo -e "\t G="$genome
     echo -e "\t e="$e
-    echo -e "\t x="$x
     
     
     
@@ -509,17 +494,22 @@ fi
 ############################################################
 #################### GRAPH CREATION  #######################
 ############################################################
-if [ ! -f ${graph_reused} ]; then # no graph was given or the given graph was not a file. 
+if [ $remove -eq 1 ]; then
+    rm -f $h5prefix.h5
+fi
+
+if [ ! -e $h5prefix.h5 ]; then
     T="$(date +%s)"
     echo -e "$yellow ############################################################"
     echo -e " #################### GRAPH CREATION  #######################"
     echo -e " ############################################################$reset"
 
-    graphCmd="${dbgh5_bin} -in ${read_sets}_${kissprefix}_removemeplease -out $h5prefix -kmer-size $k -abundance-min ${c_dbgh5} -abundance-max $C -solidity-kind one ${option_cores_gatb} -verbose $verbose  -skip-bcalm -skip-bglue -no-mphf -histo-max 1000000"
+    graphCmd="${dbgh5_bin} -in ${read_sets}_${kissprefix}_removemeplease -out $h5prefix -kmer-size $k -abundance-min ${c_dbgh5} -abundance-max $C -solidity-kind one ${option_cores_gatb} -verbose $verbose  -skip-bcalm -skip-bglue -no-mphf"
     echo $green${graphCmd}$cyan
     if [[ "$wraith" == "false" ]]; then
         ${graphCmd}
     fi
+
     if [ $? -ne 0 ]
     then
         echo "$red there was a problem with graph construction$ reset"
@@ -530,10 +520,10 @@ if [ ! -f ${graph_reused} ]; then # no graph was given or the given graph was no
     if [[ "$wraith" == "false" ]]; then
         echo "$yellow Graph creation time in seconds: ${T}$reset"
     fi
-    graph_reused=$h5prefix.h5
+
 else
     if [[ "$wraith" == "false" ]]; then
-        echo -e "$yellow File ${graph_reused} exists. We use it as input graph$reset"
+        echo -e "$yellow File $h5prefix.h5 exists. We use it as input graph$reset"
     fi
 fi
 
@@ -552,7 +542,7 @@ T="$(date +%s)"
 echo -e "$yellow ############################################################"
 echo -e " #################### KISSNP2 MODULE  #######################"
 echo -e " ############################################################$reset"
-kissnp2Cmd="${kissnp2_bin} -in ${graph_reused} -out $kissprefix  -b $b $l $x -P $P  -D $D $extend $option_cores_gatb -coverage_file ${h5prefix}_cov.h5 -max_ambigous_indel ${max_ambigous_indel} ${option_max_symmetrical_crossroads}  -verbose $verbose"
+kissnp2Cmd="${kissnp2_bin} -in $h5prefix.h5 -out $kissprefix  -b $b $l $x -P $P  -D $D $extend $option_cores_gatb $output_coverage_option -coverage_file ${h5prefix}_cov.h5 -max_ambigous_indel ${max_ambigous_indel} ${option_max_symmetrical_crossroads}  -verbose $verbose"
 echo $green${kissnp2Cmd}$cyan
 if [[ "$wraith" == "false" ]]; then
     ${kissnp2Cmd}
@@ -596,10 +586,11 @@ fi
 #######################################################################
 
 T="$(date +%s)"
+if [[ "$wraith" == "false" ]]; then
     echo -e "$yellow #############################################################"
     echo -e " #################### KISSREADS MODULE #######################"
     echo -e " #############################################################$reset"
-
+fi
 
 smallk=$k
 if (( $smallk>31 ))  ; then
@@ -611,13 +602,7 @@ index_stride=$(($i+1)); size_seed=$(($smallk-$i)) # DON'T modify this.
 if [ ! -z "${read_sets_kissreads}" ]; then
     read_sets=${read_sets_kissreads}
 fi
-
-if [ $aav -eq 1 ]; then
-    rmcmd="rm -f ${h5prefix}_cov.h5"
-    echo $green${rmcmd}$cyan
-    $rmcmd # erase this file so all predictions are coherent after kissreads
-fi
-kissreadsCmd="${kissreads2_bin} -predictions $kissprefix.fa -reads  ${read_sets}_${kissprefix}_removemeplease -co ${kissprefix}_coherent -unco ${kissprefix}_uncoherent -k $k -size_seeds ${size_seed} -index_stride ${index_stride} -hamming $d  $genotyping -coverage_file ${h5prefix}_cov.h5 $option_cores_gatb  -verbose $verbose ${option_phase_variants}"
+kissreadsCmd="${kissreads2_bin} -predictions $kissprefix.fa -reads  $read_sets -co ${kissprefix}_coherent -unco ${kissprefix}_uncoherent -k $k -size_seeds ${size_seed} -index_stride ${index_stride} -hamming $d  $genotyping -coverage_file ${h5prefix}_cov.h5 $option_cores_gatb  -verbose $verbose $y ${option_phase_variants}"
 
 echo $green $kissreadsCmd$cyan
 if [[ "$wraith" == "false" ]]; then
@@ -638,12 +623,9 @@ T="$(($(date +%s)-T))"
 #################### SORT AND FORMAT  RESULTS #########################
 #######################################################################
 
-if [[ "$wraith" == "false" ]]; then
 echo -e "$yellow ###############################################################"
 echo -e " #################### SORT AND FORMAT  RESULTS #################"
 echo -e " ###############################################################$reset"
-fi
-
 if [[ "$wraith" == "false" ]]; then
     sort -rg ${kissprefix}_coherent | cut -d " " -f 2 | tr ';' '\n' > ${kissprefix}_coherent.fa
 fi
