@@ -130,8 +130,8 @@ function help {
     echo -e "\t\t2: No limitation on branching (lowers the precision, high recall)"
     echo -e "\t -s | --symmetrical value <int value>"
     echo -e "\t\t In -b 2 mode only: maximal number of symmetrical crossroads traversed while trying to close a bubble. Default: no limit"
-    echo -e "\t -g | --graph"
-    echo -e "\t\t Reuse a previously created graph (.h5 file) with same prefix and same k and c parameters (here, contrary to discoSnp++.sh, no graph file can be specified)."
+    echo -e "\t -g | --graph <file name>"
+    echo -e "\t\t Reuse a previously created graph (.h5 file) with same prefix and same k and c parameters."
     echo -e "\t -X\t Stop discoSnp++ right after variant calling - the output is only a fasta file with no coverage information."
     echo -e "\t -D | --deletion_max_size <int>"
     echo -e "\t\t discoSnp++ will search for deletions of size from 1 to D included. Default=100"
