@@ -16,58 +16,55 @@ def set_indexes_from_gfa(gfa_file_name):
         if line[0]!="S": continue # not a compacted fact
         line=line.strip().split()
         compactedfact_id = line[1]
-        facts[compactedfact_id]=[] # stored as a set to conserve the variants order, needed for computing AC.
+        facts[compactedfact_id]=set()
         for value in line[2].strip().split(';')[:-1]:
-            facts[compactedfact_id].append(value)
             snp_id=get_left_clean_snp(value) # from ' -587h' to '587h'
+            facts[compactedfact_id].add(snp_id)
             if snp_id[:-1] not in snp_to_fact_id:
                 snp_to_fact_id[snp_id[:-1]]=set()
             snp_to_fact_id[snp_id[:-1]].add(compactedfact_id)
     mfile.close()
     return facts, snp_to_fact_id
     
+    
 
-query_sign = lambda s : "-" if s[0]=="-" else "+"   
-
-def compatibles(raw_fact,compacted_fact):
-    """"given a raw fact, detects if it is totaly included into the compacted_fact[i]
+def compatibles(raw_fact,i,compacted_facts):
+    """"given a raw fact, detects if it is (at least partly) included into the compacted_fact[i]
     we already know that the 2 facts share at least a snp
     This methods detects if there exists or not a snp, with distinct alleles in the two facts (eg 1000h in one fact, 1000l in the other). 
     Returns false in this case, True else. 
     When True is returned, a second boolean value is returned. 
-    It is set to True of the raw fact and the compacted_fact are in the same orientation, else it is set to false
+    It is set to True of the raw fact and the compacted_facts[i] are in the same orientation, else it is set to false
     """
-
-    ## index query facts:
-    query_fact_to_hl = {}
-    query_fact_to_pm = {}
-    for variant in raw_fact:
-        id_only = variant.lstrip('-')[:-1]
-        query_fact_to_pm[id_only] = query_sign(variant)
-        query_fact_to_hl[id_only] = variant[-1]
-
-    ## checks that all variants from the raw fact are included in the compacted_fact: 
-    for variant in raw_fact:
-        if variant not in compacted_fact and variant.lstrip('-') not in compacted_fact and '-'+variant not in compacted_fact : 
-            return False, None
-
-    ## check compacted fact vs query fact
-    same_direction  = False
-    direction_set   = False
-    for variant in compacted_fact:
-        id_only = variant.lstrip('-')[:-1]
-        if id_only not in query_fact_to_hl: continue
-        sign = query_sign(variant)
-        if variant[-1] != query_fact_to_hl[id_only]: return False, None
-        # check sign
-        if not direction_set: 
-            direction_set = True
-            same_direction =  (sign == query_fact_to_pm[id_only])
-        else:
-            if same_direction and sign != query_fact_to_pm[id_only]: return False, None
-            if not same_direction and sign == query_fact_to_pm[id_only]: return False, None
-    assert (direction_set)
-    return True, same_direction
+    # print (compacted_facts[i])
+    # print(raw_fact)
+    compacted_fact_i_dict = {} # snps id ->  h or l
+    query_snp_sign=''
+    for snp in compacted_facts[i]:
+        if snp[0]=='-': query_snp_sign='-'
+        else:           query_snp_sign='+'
+        snp=snp.lstrip('-')     # remove the sign
+        compacted_fact_i_dict[snp[:-1]]=snp[-1]
+    
+    nb_shared=0
+    
+    target_snp_sign=''
+    for snp in raw_fact:
+        if snp[0]=='-': target_snp_sign='-'
+        else:           target_snp_sign='+'
+        snp=snp.lstrip('-')                                 # remove the sign
+        if snp[:-1] in compacted_fact_i_dict:
+            if compacted_fact_i_dict[snp[:-1]]!=snp[-1]:    # distinct alleles 
+                # print ("            INCOMPATIBLE        ", snp, compacted_facts[i])
+                return False,query_snp_sign==target_snp_sign
+            else :
+                nb_shared+=1
+        # else: return False      # uncomment if one needs the raw fact to be fully inlcuded in the compacted_facts[i]
+    if nb_shared>1: # at least two shared alleles to link two facts.  # note that if test >1 one may avoid lot of computations upstream.
+        return True,query_snp_sign==target_snp_sign
+    if len(raw_fact)==nb_shared or len(compacted_facts[i])==nb_shared: # the raw fact or the compacted fact is fully mapped
+        return True,query_snp_sign==target_snp_sign
+    return False,query_snp_sign==target_snp_sign
     
 
 def get_compatible_facts(text_raw_fact, compacted_facts, snp_to_fact_id):
@@ -84,27 +81,33 @@ def get_compatible_facts(text_raw_fact, compacted_facts, snp_to_fact_id):
     result = set()                              # Stores the id of the compacted facts that are compatible with the input text_raw_fact
     text_raw_fact=text_raw_fact.rstrip(';')     #Avoids an empty value when splitting with ';'
     for oriented_allele in text_raw_fact.split(";"):
+        # print("oriented_allele -"+oriented_allele+"-")
         snp_id_only=get_left_clean_snp(oriented_allele).split("_")[0][:-1]      # get the snp id non oriented
+        # print("snp_id_only",snp_id_only)
         if snp_id_only in snp_to_fact_id: # the snp may be absent in case it was removed by the sequence concatenation process. 
             subcompacedfacts=subcompacedfacts.union(snp_to_fact_id[snp_id_only])    # fill the subcompacedfacts with all facts in which the snp id non oriented occurs. 
+            # print("subcompacedfacts", subcompacedfacts)
             raw_fact_snps.add(oriented_allele.split("_")[0])
+    # print ("raw_fact_snps", raw_fact_snps)
     for j in subcompacedfacts:
-        cmpt,same_orientation = compatibles(raw_fact_snps, compacted_facts[j])
+        cmpt,same_orientation = compatibles(raw_fact_snps, j, compacted_facts)
         if cmpt:
             if same_orientation:    result.add(int(j))
             else:                   result.add(-int(j))
             
+    # sys.stderr.write(f"{result}\n")
     return result
 
 
 get_allele_id = lambda x: x.split("_")[-1]+x.split("_")[1][0]   #>SNP_higher_path_9 to "9h"
 get_coverage  = lambda x: int(x.split("_")[-1])                 #C1_31 to int(31)
-def index_allele_coverage(raw_disco_fa_file_name, read_set_id, alleles_coverage = {}):
+def index_allele_coverage(raw_disco_fa_file_name, read_set_id):
     """
     For each allele name (eg 21112l) provides its coverage in the considered read set)
     Returns a dictionary: allele_id -> coverage
     Used only by "detects_allele_coverage"
     """
+    alleles_coverage = {}                    # Fora each allele, store its read coverage
     mfile = open(raw_disco_fa_file_name)
     # first variant rteated appart to recover the position of the coverage in which we are interested
     coverage_field=-1
@@ -143,21 +146,27 @@ def index_allele_coverage(raw_disco_fa_file_name, read_set_id, alleles_coverage
     mfile.close()
     return alleles_coverage
 
-def detects_allele_coverage(compacted_facts, raw_disco_co_file_name, raw_disco_unco_file_name, read_set_id):
+def detects_allele_coverage(compacted_facts, raw_disco_file_name, read_set_id):
     """
-    Given the compacted facts indexed and the raw disco output: 
-    for each compacted fact, find all allele that belong to it and store its coverage
+    Given the compacted facts indexed and the raw disco output: for each compacted fact, find all allele that belong to it and compute its estimated coverage (average, min, max)
     Returns a dictionary: compacted_fact_id -> allele_weight
     """
-    alleles_coverage = index_allele_coverage(raw_disco_co_file_name, read_set_id)
-    alleles_coverage = index_allele_coverage(raw_disco_unco_file_name, read_set_id, alleles_coverage)
+    alleles_coverage = index_allele_coverage(raw_disco_file_name, read_set_id)
     compacted_fact_allele_weight = {}              # For each compacted fact id, stores its weight
     for fact_id, fact_value in compacted_facts.items():
-        compacted_fact_allele_weight[fact_id] = []
 
+        min = sys.maxsize
+        max = -1
+        nb = 0
+        sum=0
         for allele_id in fact_value: #{'10540l', '4734l', '29633h'}
-            allele_coverage = alleles_coverage[get_left_clean_snp(allele_id)]
-            compacted_fact_allele_weight[fact_id].append(allele_coverage)
+            allele_coverage = alleles_coverage[allele_id]
+            if allele_coverage<min: min=allele_coverage
+            if allele_coverage>max: max=allele_coverage
+            sum+=allele_coverage
+            nb+=1
+        compacted_fact_allele_weight[fact_id] = [min,max,sum/float(nb)] #min, max, mean
+        # print(compacted_fact_allele_weight[fact_id])
     return compacted_fact_allele_weight
 
 def detects_facts_coverage(compacted_facts, snp_to_fact_id, raw_facts_file_name):
@@ -165,7 +174,7 @@ def detects_facts_coverage(compacted_facts, snp_to_fact_id, raw_facts_file_name)
     Given the compacted facts indexed and the raw phasing information: for each compacted fact, find all facts that belong to it and compute its estimated coverage
     Returns a dictionary: compacted_fact_id -> weight
     """
-    compacted_fact_weight = {}              # For each compacted fact id (int), stores its weight
+    compacted_fact_weight = {}              # For each compacted fact id, stores its weight
     mfile = open(raw_facts_file_name)
     for line in mfile.readlines():
         if line[0]=="#" : continue          # comment
@@ -192,33 +201,16 @@ def print_facts(phasing_file,compacted_fact_weight, compacted_fact_allele_weight
         line=line.strip()
         compacted_fact_id=int(line.split()[1])
         fact_weight=0
-        # assert (compacted_fact_id in compacted_fact_weight)
-        fact_weight = compacted_fact_weight[compacted_fact_id]
-
-        # assert(str(compacted_fact_id) in compacted_fact_allele_weight)
-
-        alleles_weight = compacted_fact_allele_weight[str(compacted_fact_id)]
-        
-
-
-
-        print(f"{str(line)}\tFC:i:{str(fact_weight)}\tmin:{min(alleles_weight)}\tmax:{max(alleles_weight)}\tmean:{sum(alleles_weight)/len(alleles_weight)}\tAC:{';'.join(str(e) for e in alleles_weight)};")
-        # print(line+"\tFC:i:"+str(fact_weight)+"\tRC:i:"+str(alleles_weight[1])+"\tmin:i:"+str(alleles_weight[0])+"\tmax:i:"+str(alleles_weight[1])+"\tmean:i:"+str(alleles_weight[2]))  ## RC is max ([1]) as we take the max (17/02/2020)
+        if compacted_fact_id in compacted_fact_weight: 
+            fact_weight = compacted_fact_weight[compacted_fact_id]
+        alleles_weight=0
+        if str(compacted_fact_id) in compacted_fact_allele_weight: 
+            alleles_weight = compacted_fact_allele_weight[str(compacted_fact_id)]
+        print(line+"\tFC:i:"+str(fact_weight)+"\tRC:i:"+str(alleles_weight[1])+"\tmin:i:"+str(alleles_weight[0])+"\tmax:i:"+str(alleles_weight[1])+"\tmean:i:"+str(alleles_weight[2]))  ## RC is max ([1]) as we take the max (17/02/2020)
         cpt+=1
     sys.stderr.write(str(cpt)+" facts written\n")
     mfile.close()
 
-def add_pair_edge (pair_edges, left, right, abundance):
-    """
-    Add a new pair to all stored pairs. Creates cells and dictionary if needed
-    Stores a canonical representation of pairs (smallest id left)
-    """
-    if left > right: left, right = right, left # swap values if left > right, in order to avoid a -> b and -b -> -a
-    if left not in pair_edges: pair_edges[left]={}
-    if right not in pair_edges[left]: pair_edges[left][right]=0
-    pair_edges[left][right]+=abundance
-
-
 def detects_pairs_of_linked_compacted_paths(compacted_facts, snp_to_fact_id, raw_facts_file_name, fact_overlaps):
     """
     given the compacted facts indexed and the raw phasing information, detects pairs of facts that are co-mapped by at least one pair of paired non compacted facts
@@ -228,10 +220,10 @@ def detects_pairs_of_linked_compacted_paths(compacted_facts, snp_to_fact_id, raw
     mfile = open(raw_facts_file_name)
     for line in mfile.readlines():
         if line[0]=="#" : continue          # comment
-        abundance = int(line.strip().split("=>")[1])
         line=line.strip().split("=>")[0]    # remove coverage
         line=line.strip().split()        # two pairs
         if len(line)<2: continue            # we consider only pairs of facts
+        # print(line)
         # for the first fact, detects all compacted_facts in which it occurs: 
         left_compacted_facts = get_compatible_facts(line[0], compacted_facts, snp_to_fact_id)
         # for the second fact, detects all compacted_facts in which it occurs: 
@@ -239,13 +231,16 @@ def detects_pairs_of_linked_compacted_paths(compacted_facts, snp_to_fact_id, raw
         ### if compacted facts matched, make all pairs
         if len(left_compacted_facts)>0 and len(right_compacted_facts)>0:
             for left_compacted_fact_id in left_compacted_facts:
+                if left_compacted_fact_id not in pair_edges:
+                    pair_edges[left_compacted_fact_id]={}
                 for right_compacted_fact_id in right_compacted_facts:
                     if left_compacted_fact_id in fact_overlaps and right_compacted_fact_id in fact_overlaps[left_compacted_fact_id]:
                         continue    # this pair only retreives two facts that overlap
                     if right_compacted_fact_id in fact_overlaps and left_compacted_fact_id in fact_overlaps[right_compacted_fact_id]:
                         continue    # this pair only retreives two facts that overlap
-
-                    add_pair_edge(pair_edges, left_compacted_fact_id, right_compacted_fact_id, abundance)
+                    if right_compacted_fact_id not in pair_edges[left_compacted_fact_id]:
+                        pair_edges[left_compacted_fact_id][right_compacted_fact_id]=0
+                    pair_edges[left_compacted_fact_id][right_compacted_fact_id]+=1
 
     mfile.close()
     return pair_edges 
@@ -266,7 +261,7 @@ def print_pair_edges_gfa_style(pair_edges, occurrence_min=1):
             
             
             
-            if pair_edges[left_fact_id][right_fact_id]>=occurrence_min:
+            if left_fact_id < right_fact_id and pair_edges[left_fact_id][right_fact_id]>=occurrence_min:
                 cpt+=1
                 print ("L\t"+str(abs_left_fact_id)+"\t"+left_sign+"\t"+str(abs_right_fact_id)+"\t"+right_sign+"\t0M\tFC:i:"+str(pair_edges[left_fact_id][right_fact_id]))
     sys.stderr.write(str(cpt)+" paired fact written\n")
@@ -334,15 +329,17 @@ def print_pairs_of_edges_sharing_snp(facts_shared_snps):
     sys.stderr.write(str(cpt)+" pairs of facts sharing at least one snp written\n")
 
 
-def main (phasing_file,raw_facts_file_name, raw_disco_co_file_name, raw_disco_unco_file_name, read_set_id):
+def main (phasing_file,raw_facts_file_name, raw_disco_file_name, read_set_id):
     sys.stderr.write("#INDEX FACTS\n")
     compacted_facts, snp_to_fact_id = set_indexes_from_gfa(phasing_file)
+
+
     
     sys.stderr.write("#COMPUTE THE COMPACTED FACT COVERAGES\n")
     compacted_fact_weight = detects_facts_coverage(compacted_facts, snp_to_fact_id, raw_facts_file_name)
     
     sys.stderr.write("#COMPUTE THE COMPACTED FACT ALLELE COVERAGES\n")
-    compacted_fact_allele_weight=detects_allele_coverage(compacted_facts, raw_disco_co_file_name, raw_disco_unco_file_name, read_set_id)
+    compacted_fact_allele_weight=detects_allele_coverage(compacted_facts, raw_disco_file_name, read_set_id)
     
     sys.stderr.write("#PRINT COMPACTED FACTS \n")
     print_facts(phasing_file,compacted_fact_weight, compacted_fact_allele_weight)
@@ -362,7 +359,7 @@ def main (phasing_file,raw_facts_file_name, raw_disco_co_file_name, raw_disco_un
     
     
 if __name__ == "__main__":
-    main(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4],  sys.argv[5]) # compacted_facts.gfa phased_alleles_read_set_id_1.txt discoRes_k_31_c_2_D_0_P_3_b_2_coherent.fa discoRes_k_31_c_2_D_0_P_3_b_2_uncoherent.fa 1
+    main(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4]) # compacted_facts.gfa phased_alleles_read_set_id_1.txt discoRes_k_31_c_2_D_0_P_3_b_2_coherent.fa 1
 
     
     
\ No newline at end of file
