@@ -1,11 +1,7 @@
 import sys
 import K3000_gfa_post_treatment as gpt # :)
-import warnings
-# from deprecated import deprecated
 
 
-################# 28 APRIL 2020 - Now this script is managed by Kerian Thuillier    ##################
-################# No more maintained                                                ##################
 
 """
 #id of forward and reverse nodes
@@ -42,7 +38,7 @@ p2	m2
 ;
 #set of edges. Four types of edges, 1/ "overlaps" edges, that show an overlap between facts and 2/ "links" edges, that represent facts linked by paired reads (distanace unknown) and 3/ "successive" edges that represent two successive facts (without phasing) and 4/ "incompatible" edges, no path should contain two nodes linked by such an edge 
 set Edges :=
-p0	m55	overlaps 
+p0	m55	overlaps #TODO (plus tard): il faut aussi doubler les arêtes et donc générer p55	m0	overlaps (pas d'ordre à respecter au sein de chaque champ)
 p0	m53	overlaps
 p1	m55	overlaps
 p303	p305	links
@@ -89,35 +85,8 @@ p320	m388	successive	0
 
 def print_header():
     print("#haplotype number")
-    print("# *** note about abundances ***")
-    print("#  This file contains four values of abundances per fact")
-    print("#   - ab_min: the coverage of the less covered variant of the fact")
-    print("#   - ab_max: the coverage of the most covered variant of the fact")
-    print("#   - ab_avg: the average coverage of the variants of the fact")
-    print("#   - ab_comapped: total number of reads i/ mapped on the fact and ii/ mapping at least two variants of the fact")
-    print("#  Full example")
-    print("#  *  *  *  *  *  *      (variant positions on the fact)")
-    print("#  --------              (read mapping at least two variants)")
-    print("#    --------            (read mapping at least two variants)")
-    print("#    -----               (read mapping at least two variants)")
-    print("#       --------         (read mapping at least two variants)")
-    print("#             ----       (read mapping at least two variants)")
-    print("#          --------      (read mapping at least two variants)")
-    print("# --                     (read mapping one variant)")
-    print("# --                     (read mapping one variant)")
-    print("#    --                  (read mapping one variant)")
-    print("#       --               (read mapping one variant)")
-    print("#       --               (read mapping one variant)")
-    print("#          --            (read mapping one variant)")
-    print("#             --         (read mapping one variant)")
-    print("#                --      (read mapping one variant)")
-    print("#  3  4  6  4  4  2  (for each variant how many reads mapped on it)")
-    print("#  Here: ab_comapped=6, ab_min=2, ab_max=6, ab_avg=3.84")
-    print("# *** End note about abundances ***")
-    
     print("param mult := XXX")
-    
-oposite_sign = lambda x: "m" if x == "p" else "p"
+
 
 def print_nodes(gfa_file_name, DG=None):
     print("#id of plus (p) and minus (m) nodes")
@@ -127,7 +96,7 @@ def print_nodes(gfa_file_name, DG=None):
         if not line: break
         line=line.strip()
         if line[0]=="S":
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
+            "S       0       28175h;10031h;12786h;-41223l;-26670h; SP:0_426;383_541;427_586;542_661;587_731; BP:0_93;-17_61;54_61;-16_61;14_84;      FC:i:64 RC:i:21"
             node_id = line.split()[1]
             if DG and node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
             print("p"+node_id)  # 'p' stands for "plus strand"
@@ -135,8 +104,6 @@ def print_nodes(gfa_file_name, DG=None):
     print(";")
     gfa_file.close()
     
-    
-    
 def print_nodes_number_loci(gfa_file_name, DG=None):
     print("#id of nodes with their number of variants")
     print("param length :=")
@@ -146,54 +113,23 @@ def print_nodes_number_loci(gfa_file_name, DG=None):
         if line[0]=="S":
             node_id=line.split()[1]
             if DG and node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
+            "S       0       28175h;10031h;12786h;-41223l;-26670h; SP:0_426;383_541;427_586;542_661;587_731; BP:0_93;-17_61;54_61;-16_61;14_84;      FC:i:64 RC:i:21"
             print("p"+node_id+"\t"+str(len(line.split()[2].strip(";").split(";"))))
             print("m"+node_id+"\t"+str(len(line.split()[2].strip(";").split(";"))))
     print(";")
     gfa_file.close()
 
-def print_nodes_ab_min(gfa_file_name, DG=None):
-    print("#id of nodes with their ab_min coverage")
-    print("param ab_min :=")
+def print_nodes_weight(gfa_file_name, DG=None):
+    print("#id of nodes with their coverage. Here coverage refers to the read coverage of the less covered allele of all alleles of the fact")
+    print("param ab :=")
     gfa_file = open(gfa_file_name)
     for line in gfa_file.readlines():
         line=line.strip()
         if line[0]=="S":
             node_id=line.split()[1]
             if DG and node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
+            "S       0       28175h;10031h;12786h;-41223l;-26670h; SP:0_426;383_541;427_586;542_661;587_731; BP:0_93;-17_61;54_61;-16_61;14_84;      FC:i:64 RC:i:21"
             print("p"+node_id+"\t"+line.split()[6].split(":")[-1])
-            assert(line.split()[6].split(":")[0]=="min")
-    print(";")
-    gfa_file.close()
-    
-def print_nodes_ab_max(gfa_file_name, DG=None):
-    print("#id of nodes with their ab_max coverage")
-    print("param ab_max :=")
-    gfa_file = open(gfa_file_name)
-    for line in gfa_file.readlines():
-        line=line.strip()
-        if line[0]=="S":
-            node_id=line.split()[1]
-            if DG and node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
-            print("p"+node_id+"\t"+line.split()[7].split(":")[-1])
-            assert(line.split()[7].split(":")[0]=="max")
-    print(";")
-    gfa_file.close()
-    
-def print_nodes_ab_avg(gfa_file_name, DG=None):
-    print("#id of nodes with their ab_avg coverage")
-    print("param ab_avg :=")
-    gfa_file = open(gfa_file_name)
-    for line in gfa_file.readlines():
-        line=line.strip()
-        if line[0]=="S":
-            node_id=line.split()[1]
-            if DG and node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
-            print("p"+node_id+"\t"+line.split()[8].split(":")[-1])
-            assert(line.split()[8].split(":")[0]=="mean")
     print(";")
     gfa_file.close()
     
@@ -207,9 +143,8 @@ def print_nodes_weight_phased_alleles(gfa_file_name, DG=None):
         if line[0]=="S":
             node_id=line.split()[1]
             if DG and node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
+            "S       0       28175h;10031h;12786h;-41223l;-26670h; SP:0_426;383_541;427_586;542_661;587_731; BP:0_93;-17_61;54_61;-16_61;14_84;      FC:i:64 RC:i:21"
             print("p"+node_id+"\t"+line.split()[5].split(":")[-1])
-            assert(line.split()[5].split(":")[0]=="FC")
     print(";")
     gfa_file.close()
     
@@ -221,7 +156,7 @@ def print_reverse(gfa_file_name,DG=None):
     for line in gfa_file.readlines():
         line=line.strip()
         if line[0]=="S":
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
+            "S       0       28175h;10031h;12786h;-41223l;-26670h; SP:0_426;383_541;427_586;542_661;587_731; BP:0_93;-17_61;54_61;-16_61;14_84;      FC:i:64 RC:i:21"
             node_id=line.split()[1]
             if DG and node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
             print("p"+node_id+"\t"+"m"+line.split()[1])  # 'p' stands for "plus strand"
@@ -236,7 +171,7 @@ def print_nodes_connected_components(gfa_file_name, DG):
     for line in gfa_file.readlines():
         line=line.strip()
         if line[0]=="S":
-            "S       0       1234h;-1354h;977h;577h; SP:0_54;53_96;64_117;84_128;    BP:0_41;6_41;-25_41;-26_41;     FC:i:579        min:410 max:467 mean:441.5      AC:436;467;453;410;"
+            "S       0       28175h;10031h;12786h;-41223l;-26670h; SP:0_426;383_541;427_586;542_661;587_731; BP:0_93;-17_61;54_61;-16_61;14_84;      FC:i:64 RC:i:21"
             node_id=line.split()[1]
             if node_id not in DG.nodes(): continue       # this node was removed during gfa post treatment
             cc_id = DG.nodes[node_id]['cc_id']
@@ -246,77 +181,28 @@ def print_nodes_connected_components(gfa_file_name, DG):
     gfa_file.close()
     
     
-# @deprecated(reason="Not used anymore, redundant with function `already_used` generic for all kind of links")
-# def printable_successive(printed_successive, source_id, target_id):
-#
-#     """
-#     1/ checks of source_id <-> target_id not already in printed_successive. If already inside, do nothing and returns false
-#     2/ [else] add target_id in source_id key and return true
-#     """
-#     # source is always the smallest, avoid to test both directions.
-#     if target_id < source_id:
-#         tmp = source_id
-#         source_id = target_id
-#         target_id = tmp
-#     if source_id in printed_successive and target_id in printed_successive[source_id]: return False
-#
-#     if source_id not in printed_successive: printed_successive[source_id] = []
-#     printed_successive[source_id].append(target_id)
-#     return True
-    
-
-def already_used(edges,sign_source,source_id,sign_target,target_id,type):
-    """ detects if the edge had already been used 
-    This is necessary to avoid duplicated edges. 
-    For instance if the gfa contains: 
-    L	571	+	829	-	-1M
-    ...
-    L	829	+	571	-	-1M
-    Then, the line is duplicated as it contains the same piece of information. 
-    Hence we have to store the fact that the edge was already printed with: L	571	+	829	-	-1M for instance. 
-    We do this by storing for the lowest node id.
+def printable_successive(printed_successive, source_id, target_id):
     """
-    if type not in edges: edges[type] = {}
-    if source_id > target_id:
-        if sign_source == "m": sign_source="p"
-        else: sign_source = "m"
-        if sign_target == "m": sign_target="p"
-        else: sign_target = "m"
+    1/ checks of source_id <-> target_id not already in printed_successive. If already inside, do nothing and returns false
+    2/ [else] add target_id in source_id key and return true
+    """
+    # source is always the smallest, avoid to test both directions.
+    if target_id < source_id: 
         tmp = source_id
         source_id = target_id
         target_id = tmp
-        
-    source = sign_source+source_id
-    target = sign_target+target_id
-    already = True
-    if source not in edges[type]:
-        edges[type][source] = set()
-    if target not in edges[type][source]:
-        edges[type][source].add(target)
-        already = False
+    if source_id in printed_successive and target_id in printed_successive[source_id]: return False
+    
+    if source_id not in printed_successive: printed_successive[source_id] = []
+    printed_successive[source_id].append(target_id)
+    return True
     
-    if type == "successive":
-        sign_source = oposite_sign(sign_source)
-        sign_target = oposite_sign(sign_target)
-        source = sign_source+source_id
-        target = sign_target+target_id
-        if source not in edges[type]:
-            edges[type][source] = set()
-        if target not in edges[type][source]:
-            edges[type][source].add(target)
-            already = False
-            
-    return already
-
-
-
 
 def print_edges(gfa_file_name, DG=None):
     print("#set of edges. Four types of edges, 1/ \"overlaps\" edges, that show an overlap between facts and 2/ \"links\" edges, that represent facts linked by paired reads (distanace unknown) and 3/ \"successive\" edges that represent two successive facts (without phasing) and 4/ \"incompatible\" edges, no path should contain two nodes linked by such an edge ")
-    printed_edges = {}
     print("set Edges :=")
     gfa_file = open(gfa_file_name)
-    # printed_successive = {} # key = id, target = [ids]. Used to retain which successive links ad been writen, avoiding redundancies
+    printed_successive = {} # key = id, target = [ids]. Used to retain which successive links ad been writen, avoiding redundancies
     for line in gfa_file.readlines():
         line=line.strip()
         if line[0]=="L":
@@ -336,26 +222,43 @@ def print_edges(gfa_file_name, DG=None):
             if overlap_len==0: type="links"
             if overlap_len==-1: type="successive"
             if overlap_len==-2: type="incompatibles"
-            if already_used(printed_edges,sign_source,source_id,sign_target,target_id,type): continue
             if type == "overlaps" or type=="successive" or type=="links": 
                 print(sign_source+source_id+"\t"+sign_target+target_id+"\t"+type)  
                 # print the reverse of these nodes
-                sign_source = oposite_sign(sign_source)
-                sign_target = oposite_sign(sign_target)
+                if sign_source == "m": sign_source="p"
+                else: sign_source = "m"
+                if sign_target == "m": sign_target="p"
+                else: sign_target = "m"
                 print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type)
+                
+                
+                
+            
             else: # All those nodes are non oriented - need all possible combinations
+                # if type=="successive" and  not printable_successive(printed_successive, source_id, target_id): continue
+                # if type=="links":
+                #     sign_source = "p"
+                #     sign_target = "p"
+                #     print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type)
+                #     continue
                 for sign_source in "m","p":
                     for sign_target in "m", "p":
                         print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type)
+                        # if type=="successive":              # in case of successive edges, one needs to indicate all possibilities p/m and forward and reverse
+                        #     print(sign_source+source_id+"\t"+sign_target+target_id+"\t"+type)
+                
+            
+                
+            
+            # do not print other edges (unitig linked and snp linked)
     print(";")
     gfa_file.close()
     
 def print_edge_coverages(gfa_file_name, DG=None):
     print ("#Coverage of the pairend links. Note that overlap links do not have any coverage (just computed from fact overlaps). Also incompatible and successive links do not have coverage, by definition. ")
     print ("param pairend_end_links_coverage :=")
-    printed_edges = {}
     gfa_file = open(gfa_file_name)
-    # printed_successive = {} # key = id, target = [ids]. Used to retain which successive links ad been writen, avoiding redundancies
+    printed_successive = {} # key = id, target = [ids]. Used to retain which successive links ad been writen, avoiding redundancies
     for line in gfa_file.readlines():
         line=line.strip()
         if line[0]=="L":
@@ -379,28 +282,47 @@ def print_edge_coverages(gfa_file_name, DG=None):
                 coverage = int(line.split()[6].split(":")[-1])
             if overlap_len==-1: type="successive"
             if overlap_len==-2: type="incompatibles"
-
-            if already_used(printed_edges,sign_source,source_id,sign_target,target_id,type): continue
+            # print(sign_source+source_id+"\t"+sign_target+target_id+"\t"+type+"\t"+str(coverage))
+#             # do not print other edges (unitig linked and snp linked)
+#             # print the reverse of these nodes
+#             if sign_source == "m": sign_source="p"
+#             else: sign_source = "m"
+#             if sign_target == "m": sign_target="p"
+#             else: sign_target = "m"
+#             print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type+"\t"+str(coverage))
+#
             if type == "overlaps"  or type=="successive" or type=="links": 
                 print(sign_source+source_id+"\t"+sign_target+target_id+"\t"+type+"\t"+str(coverage))  
                 # print the reverse of these nodes
-                sign_source = oposite_sign(sign_source)
-                sign_target = oposite_sign(sign_target)
+                if sign_source == "m": sign_source="p"
+                else: sign_source = "m"
+                if sign_target == "m": sign_target="p"
+                else: sign_target = "m"
                 print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type+"\t"+str(coverage))
             
             else: # All those nodes are non oriented - need all possible combinations
+                # if type=="successive" and  not printable_successive(printed_successive, source_id, target_id): continue
+                # if type=="links":
+                #     sign_source = "p"
+                #     sign_target = "p"
+                #     print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type+"\t"+str(coverage))
+                #     continue
                 for sign_source in "m","p":
                     for sign_target in "m", "p":
                         print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type+"\t"+str(coverage))  
+                        # if type=="successive":              # in case of successive edges, one needs to indicate all possibilities p/m and forward and reverse
+                        #     print(sign_source+source_id+"\t"+sign_target+target_id+"\t"+type+"\t"+str(coverage))
+            
+            
+            
     print(";")
     gfa_file.close()
     
 def print_edges_content(gfa_file_name, DG=None):
     print("#overlap length of each edge. For an \"overlaps\" edge, it indicates the number of common variants. For any other edge type (links, successive, or incompatibles), this is set to zero")
     print("param l :=")
-    printed_edges = {}
     gfa_file = open(gfa_file_name)
-    # printed_successive = {} # key = id, target = [ids]. Used to retain which successive links ad been writen, avoiding redundancies
+    printed_successive = {} # key = id, target = [ids]. Used to retain which successive links ad been writen, avoiding redundancies
     for line in gfa_file.readlines():
         line=line.strip()
         if line[0]=="L":
@@ -431,12 +353,13 @@ def print_edges_content(gfa_file_name, DG=None):
            #  else: sign_target = "m"
            #  print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type+"\t"+str(max(0,overlap_len)))
            #           
-            if already_used(printed_edges,sign_source,source_id,sign_target,target_id,type): continue
             if type == "overlaps" or type=="successive" or type=="links": 
                 print(sign_source+source_id+"\t"+sign_target+target_id+"\t"+type+"\t"+str(max(0,overlap_len)))  
                 # print the reverse of these nodes
-                sign_source = oposite_sign(sign_source)
-                sign_target = oposite_sign(sign_target)
+                if sign_source == "m": sign_source="p"
+                else: sign_source = "m"
+                if sign_target == "m": sign_target="p"
+                else: sign_target = "m"
                 print(sign_target+target_id+"\t"+sign_source+source_id+"\t"+type+"\t"+str(max(0,overlap_len)))
             
             else: # All those nodes are non oriented - need all possible combinations
@@ -463,32 +386,22 @@ def main(gfa_file_name):
     Usage: 
         python ~/workspace/gatb-discosnp/scripts/k3000/K3000_gfa_to_dat.py graph_plus.gfa > graph_diploid.dat
     '''
-    warnings.warn(f"{sys.argv[0]} is not maintenained anymore (May 2020).", DeprecationWarning)
-    
-    
     # Store the information as a graph. 
     # This enables 
     #   to compute connected components
     #   to remove cycles
     #   to remove too large cc
     DG = None
-
-    sys.stderr.write("Storing the graph\n")
-    DG = gpt.store_graph(gfa_file_name) # store the graph without paired edges
-
-    sys.stderr.write("Detecting connected components\n")
-    gpt.assign_cc(DG)
-
-    sys.stderr.write("Removing connected compoenents with cycles\n")
-    gpt.remove_cc_with_cycles(DG)
+    if True: 
+        max_cc_size=1000
+        DG = gpt.store_graph(gfa_file_name)
+        gpt.assign_cc(DG,max_cc_size)
+        gpt.remove_cc_with_cycles(DG)
     
-    sys.stderr.write("Printing out the dat file\n")
     print_header()
     print_nodes(gfa_file_name,DG)
-    print_nodes_number_loci(gfa_file_name, DG)
-    print_nodes_ab_min(gfa_file_name,DG)
-    print_nodes_ab_max(gfa_file_name,DG)
-    print_nodes_ab_avg(gfa_file_name,DG)
+    print_nodes_number_loci(gfa_file_name, DG=None)
+    print_nodes_weight(gfa_file_name,DG)
     print_nodes_weight_phased_alleles(gfa_file_name, DG)
     print_reverse(gfa_file_name,DG)
     if DG:
