@@ -18,22 +18,7 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #*****************************************************************************
 
-# First check that python3 is installed and has version 3 or more:
-if ! hash python3; then
-    echo "python3 is not installed"
-    exit 1
-fi
-
-ver=$(python3 -V 2>&1 | sed 's/.* \([0-9]\).\([0-9]\).*/\1\2/')
-if [ "$ver" -lt "30" ]; then
-    echo "This script requires python3 3.0 or greater"
-    exit 1
-fi
-
-# Get the local directory path
 DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
-
-# Option initialisations and defaults
 remove=0
 PATH_VCF_creator=""
 samfile=""
@@ -99,7 +84,7 @@ while getopts "hB:c:G:p:wk:Ief:o:t:" opt; do
        case $opt in
 
               t)
-              bwa_threads="-t $OPTARG"
+              bwa_threads="-t ",$OPTARG
               ;;
 
               w)
@@ -226,19 +211,14 @@ if [ -z "$samfile" ];then
                      echo -e "...And the file disco : option -p..."
                      exit 1
               else
-                     echo -e " run python3 $PATH_VCF_creator/VCF_creator.py -s $discoSNPs -o $vcffile"
-                     python3 $PATH_VCF_creator/VCF_creator.py -s $discoSNPs -o $vcffile #-n $n
+
+                     python $PATH_VCF_creator/VCF_creator.py -s $discoSNPs -o $vcffile #-n $n
                      if [ $? -ne 0 ]
                      then
-                            echo "there was a problem with the VCF creation (command was \"python3 $PATH_VCF_creator/VCF_creator.py -s $discoSNPs -o $vcffile\""
+                            echo "there was a problem with the VCF creation (command was \"python $PATH_VCF_creator/VCF_creator.py -s $discoSNPs -o $vcffile\""
                             exit 1
                      fi
                      echo -e "... Creation of the vcf file : done ...==> $vcffile"
-
-                     echo -e " Transforming the created zero-based vcf onto a one-based vcf file"
-                     cmd="python3  $PATH_VCF_creator/zero2one.py -i $vcffile"
-                     echo $cmd
-                     $cmd
                      exit
               fi
        fi
@@ -279,9 +259,9 @@ if [ -z "$samfile" ];then
                      discoSNPsbis=$(basename $discoSNPs .fa)"bis.fasta"
 
                      if [ $map_with_extensions -eq 1 ];then
-                            python3 $PATH_VCF_creator/keep_extensions_disco_file.py $discoSNPs $discoSNPsbis
+                            python $PATH_VCF_creator/keep_extensions_disco_file.py $discoSNPs $discoSNPsbis
                      else
-                            python3 $PATH_VCF_creator/remove_extensions_disco_file.py $discoSNPs $discoSNPsbis
+                            python $PATH_VCF_creator/remove_extensions_disco_file.py $discoSNPs $discoSNPsbis
                      fi
                      if [ -z "$discoSNPsbis" ];then
                             echo "...Error with the script remove_extensions_disco_file.py..."
@@ -318,11 +298,11 @@ if [ -z "$samfile" ];then
        #---------------------------------------------------------------------------------------------------------------------------
        #---------------------------------------------------------------------------------------------------------------------------
        ##Alignment discosnps on the reference genome
-       echo "ALIGNMENT: $PATH_BWA/bwa mem -h 80 -k $k $genome $discoSNPsbis $bwa_threads > $samfile"
-       $PATH_BWA/bwa mem -h 80 -k $k $genome $discoSNPsbis $bwa_threads > $samfile
+       echo "ALIGNMENT: $PATH_BWA/bwa mem -h 80 -k $k $genome $discoSNPsbis > $samfile"
+       $PATH_BWA/bwa mem -h 80 -k $k $genome $discoSNPsbis > $samfile
        if [ $? -ne 0 ]
        then
-              echo "there was a problem with BWA (command was \"$PATH_BWA/bwa mem -h 80 -k $k $genome $discoSNPsbis $bwa_threads > $samfile\""
+              echo "there was a problem with BWA (command was \"$PATH_BWA/bwa mem $genome $discoSNPsbis > $samfile\""
               exit 1
        fi
        #---------------------------------------------------------------------------------------------------------------------------
@@ -340,11 +320,10 @@ else
        fi
 fi
 
-echo -e "python3 $PATH_VCF_creator/VCF_creator.py -s $samfile -o $vcffile"
-python3 $PATH_VCF_creator/VCF_creator.py -s $samfile -o $vcffile 
+python $PATH_VCF_creator/VCF_creator.py -s $samfile -o $vcffile 
 if [ $? -ne 0 ]
 then
-       echo "there was a problem with the VCF creation (command was \"python3 $PATH_VCF_creator/VCF_creator.py -s $samfile -o $vcffile \""
+       echo "there was a problem with the VCF creation (command was \"python $PATH_VCF_creator/VCF_creator.py -s $samfile -o $vcffile \""
        exit 1
 fi
 echo -e "... Creation of the vcf file: done ...==> $vcffile "
@@ -353,26 +332,15 @@ echo -e "... Creation of the vcf file: done ...==> $vcffile "
 if [ $igv -eq 1 ] ; then
        $DIR/create_IGV_compatible_VCF.sh $vcffile
        nameVCFIGV=$( basename $vcffile .vcf )
-       python3 $PATH_VCF_creator/filterOnBestDP_multiple_variant_at_same_pos.py $nameVCFIGV\_for_IGV.vcf > tmp.vcf
+       python $PATH_VCF_creator/filterOnBestDP_multiple_variant_at_same_pos.py $nameVCFIGV\_for_IGV.vcf > tmp.vcf
        if [ $? -ne 0 ]
        then
-              echo "there was a problem with the IGV VCF creation (command was \"python3 $PATH_VCF_creator/filterOnBestDP_multiple_variant_at_same_pos.py $nameVCFIGV\_for_IGV.vcf > tmp.vcf\""
+              echo "there was a problem with the IGV VCF creation (command was \"python $PATH_VCF_creator/filterOnBestDP_multiple_variant_at_same_pos.py $nameVCFIGV\_for_IGV.vcf > tmp.vcf\""
               exit 1
        fi
        echo -e "... Creation of the vcf file: done ...==> $vcffile"
        
        cat tmp.vcf > $nameVCFIGV\_for_IGV.vcf
-
-       echo -e " Transforming the created zero-based vcf (and for IGV vcf) onto one-based vcf files"
-       cmd="python3  $PATH_VCF_creator/zero2one.py -i $vcffile"
-       echo $cmd
-       $cmd
-       cmd="python3  $PATH_VCF_creator/zero2one.py -i ${nameVCFIGV}_for_IGV.vcf"
-       echo $cmd
-       $cmd
-
-
-
 fi
 
 
