@@ -53,8 +53,8 @@ Kissnp2::Kissnp2 () : Tool ("Kissnp2")
     getParser()->push_front (new OptionNoParam  (STR_DISCOSNP_LOW_COMPLEXITY,               "conserve low complexity SNPs",     false));
     getParser()->push_front (new OptionOneParam (STR_MAX_AMBIGOUS_INDELS,                   "Maximal size of ambiguity of INDELs. INDELS whose ambiguity is higher than this value are not output", false, "20"));
     getParser()->push_front (new OptionOneParam (STR_DISCOSNP_AUTHORISED_BRANCHING,         "branching mode\n"
-                                                            "\t\t0: forbid SNPs for which any of the two paths is branching (high precision, low recall)\n"
-                                                            "\t\t1: forbid SNPs for which the two paths are branching (e.g. the two paths can be created either with a 'A' or a 'C' at the same position (default value)\n"
+                                                            "\t\t0: forbid SNPs for wich any of the two paths is branching (high precision, low recall)\n"
+                                                            "\t\t1: forbid SNPs for wich the two paths are branching (e.g. the two paths can be created either with a 'A' or a 'C' at the same position (default value)\n"
                                                             "\t\t2: No limitation on branching (low precision, high recall)",  false, "1"));
     getParser()->push_front (new OptionOneParam (STR_MAX_SYMMETRICAL_CROSSROADS,"In b2 mode only: maximal number of symmetrical croasroads traversed while trying to close a bubble. Default: no limit", false, "-1"));
 
@@ -64,7 +64,7 @@ Kissnp2::Kissnp2 () : Tool ("Kissnp2")
     getParser()->push_front (new OptionOneParam (STR_KISSNP2_COVERAGE_FILE_NAME,            "File (.h5) generated by kissnp2, containing the coverage threshold per read set",                      false, "_removemeplease"));
     
     getParser()->push_front (new OptionOneParam (STR_URI_INPUT,                             "input file (likely a hdf5 file)",  true));
-    getParser()->push_front (new OptionNoParam (STR_KISSNP2_DONT_OUTPUT_FIRST_COV,          "Don't output the first coverage threshold. Use this option when the reference file is used for finding the variants",  false));
+    getParser()->push_front (new OptionNoParam (STR_KISSNP2_DONT_OUTPUT_FIRST_COV,          "Don't output the first coverage threshold. Use this option whent the refernece file is used for finding the variants",  false));
     
     
     getParser()->push_front (new OptionOneParam (STR_MAX_INDEL_SIZE,                        "maximal size of a predicted indel", false, "0"));
@@ -75,7 +75,7 @@ Kissnp2::Kissnp2 () : Tool ("Kissnp2")
     getParser()->push_back (new OptionOneParam (BubbleFinder::STR_BFS_MAX_BREADTH,          "maximum breadth for BFS",  false,  "20"));
 
     getParser()->push_front (new OptionNoParam (STR_RADSEQ,                                 "keep truncated bubbles, that have no successors on the 2 paths at the same position",  false));
-    getParser()->push_back (new OptionOneParam (STR_MAX_TRUNCATED_PATH_LENGTH_DIFFERENCE,   "Longest accepted difference length between two paths of a truncated bubble",  false,  "0"));
+    getParser()->push_back (new OptionOneParam (STR_MAX_TRUNCATED_PATH_LENGTH_DIFFERENCE,   "Longest accepted difference length between two paths of a truncated bubbleS",  false,  "0"));
     
 }
 
